get_client

Function get_client 

pub async fn get_client(
    uri: Uri,
) -> Result<CompactTxStreamerClient<Channel>, GetClientError>
The connector, containing the URI to connect to. This type is mostly an interface to the get_client method. The proto-generated CompactTxStreamerClient type is the main interface to actually communicating with a Zcash indexer. Connect to the URI, and return a Client. For the full list of methods the client supports, see the service.proto file (some of the types are defined in the compact_formats.proto file).