Crate zingo_netutils

Crate zingo_netutils 

zingo-netutils

This crate provides the GrpcConnector struct, used to communicate with an indexer.

Enums

GetClientError

Functions

get_client
The connector, containing the URI to connect to. This type is mostly an interface to the get_client method. The proto-generated CompactTxStreamerClient type is the main interface to actually communicating with a Zcash indexer. Connect to the URI, and return a Client. For the full list of methods the client supports, see the service.proto file (some of the types are defined in the compact_formats.proto file).